/*
 * This file is part of FGGL.
 *
 * FGGL is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * FGGL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with FGGL.
 * If not, see <https://www.gnu.org/licenses/>.
 */

//
// Created by webpigeon on 27/08/22.
//

#ifndef FGGL_DEMO_INCLUDE_GRID_HPP
#define FGGL_DEMO_INCLUDE_GRID_HPP

#include <memory>

#include "fggl/scenes/game.hpp"
#include "fggl/animation/animator.hpp"
#include "fggl/entity/gridworld/zone.hpp"

namespace demo {

	constexpr int GRID_SIZE = 255;
	using DemoGrid = fggl::entity::grid::Area2D<GRID_SIZE, GRID_SIZE>;

	struct Sprite {

	};

	struct CellPos {
		fggl::math::vec2i pos;
		uint8_t direction;

		fggl::math::vec2f drawOffset{0.0F, 0.0F};
		float rotationOffset{0.0F};
	};

	class GridScene : public fggl::scenes::GameBase {
		public:
			explicit GridScene(fggl::App& app);
			void activate() override;
			void deactivate() override;

			void update(float dt) override;
			void render(fggl::gfx::Graphics& gfx) override;
		private:
			fggl::entity::grid::TileSet m_tiles;
			fggl::animation::FrameAnimator m_animator;
			std::unique_ptr<DemoGrid> m_grid;

			void tickPlayer();

	};

}

#endif //FGGL_DEMO_INCLUDE_GRID_HPP
